@@ -1,7 +1,21 @@
-#ident "$Id: conf_mg.h,v 4.9 1999/02/28 19:13:08 gert Exp $ Copyright (c) 1994 Gert Doering"
+#ident "$Id: conf_mg.h,v 4.14 2018/03/06 11:39:25 gert Exp $ Copyright (c) 1994 Gert Doering"
 
 /* all (dynamic) mgetty configuration is contained in this structure.
  * It is initialized and loaded in conf_mg.c and accessed from mgetty.c
+ *
+ * $Log: conf_mg.h,v $
+ * Revision 4.14  2018/03/06 11:39:25  gert
+ * Alex Manoussakis: cid-program patch set
+ *
+ * Revision 4.13  2018/03/05 18:34:05  gert
+ * Add new config option "open-delay <msec>" (same thing as for sendfax)
+ *
+ * Feature wish from Marc Daniel Fege <marc@fege.net>, needed on some ELSAs
+ *
+ * Revision 4.12  2010/09/14 15:38:27  gert
+ * add CVS log
+ * add options for SMS processing - sms-handler, sms-handler-{user,group}
+ *
  */
 
 extern struct conf_data_mgetty {
@@ -17,6 +31,7 @@ extern struct conf_data_mgetty {
 
 	toggle_dtr,				/* toggle DTR for modem reset */
 	toggle_dtr_waittime,			/* time to hold DTR low */
+	open_delay,			/* time time to wait for draining */
 	need_dsr,				/* wait for DSR+CTS */
 	data_only,				/* no fax */
         fax_only,				/* no data */
@@ -33,6 +48,7 @@ extern struct conf_data_mgetty {
 	rings_wanted,				/* number of RINGs */
 	msn_list,				/* ISDN MSNs (dist.ring) */
 	getcnd_chat,				/* get caller ID (for ELINK)*/
+	cid_program,				/* notify about caller ID */
 	cnd_program,				/* accept caller? */
 	answer_chat,				/* ATA...CONNECT...""...\n */
 	answer_chat_timeout,			/* longer as S7! */
@@ -47,6 +63,7 @@ extern struct conf_data_mgetty {
 	login_prompt,
 	login_time,				/* max. time to log in */
 	do_send_emsi,				/* send EMSI_REQ string */
+	env_ttyprompt,				/* suppress login prompt */
 	login_config,				/* login.config file name */
 
 	station_id,				/* local fax station ID */
@@ -58,6 +75,7 @@ extern struct conf_data_mgetty {
 	fax_owner,				/* "fax" */
 	fax_group,				/* "staff" */
 	fax_mode,				/* "660" */
+	fax_spool_in,				/* "/var/fax/inc:/tmp" */
 
 	debug,					/* log level */
     
@@ -65,6 +83,11 @@ extern struct conf_data_mgetty {
         statistics_file,			/* default: log file */
 	gettydefs_tag,
         termtype,				/* $TERM=... */
+#ifdef SMS
+	sms_handler,				/* sms handler program */
+	sms_handler_user,			/* sms handler program */
+	sms_handler_group,			/* sms handler program */
+#endif
 	end_of_config; } c;
 
 int mgetty_parse_args _PROTO(( int argc, char ** argv ));
