@@ -1,7 +1,12 @@
-#ident "$Id: conf_sf.h,v 4.4 1998/06/26 13:00:23 gert Exp $ Copyright (c) 1994 Gert Doering"
+#ident "$Id: conf_sf.h,v 4.7 2010/09/17 15:27:04 gert Exp $ Copyright (c) 1994 Gert Doering"
 
 /* all (dynamic) sendfax configuration is contained in this structure.
  * It is initialized and loaded in conf_sf.c and accessed from sendfax.c
+ *
+ * $Log: conf_sf.h,v $
+ * Revision 4.7  2010/09/17 15:27:04  gert
+ * add CVS log tags
+ *
  */
 
 extern struct conf_data_sendfax {
@@ -12,6 +17,9 @@ extern struct conf_data_sendfax {
 	modem_handshake,
 	modem_type,
 	modem_quirks,
+	reset_after_fail,
+	fax_send_flow,
+	fax_rec_flow,
 	max_tries,
         max_tries_ctd,
 	speed,
