@@ -3,7 +3,7 @@
  *
  * pvffile prints out some useful information about .pvf files.
  *
- * $Id: pvffile.c,v 1.4 1998/09/09 21:07:48 gert Exp $
+ * $Id: pvffile.c,v 1.5 1999/03/16 09:59:23 marcs Exp $
  *
  */
 
@@ -17,6 +17,7 @@ static void usage (void)
      fprintf(stderr, "usage:\n");
      fprintf(stderr, "\t%s [options] [pvffile]\n", program_name);
      fprintf(stderr, "\noptions:\n");
+     fprintf(stderr, "\t-c     also print sample count\n");
      fprintf(stderr, "\t-h     this help message\n\n");
      exit(ERROR);
      }
@@ -24,6 +25,7 @@ static void usage (void)
 int main (int argc, char *argv[])
      {
      int option;
+     int cflag = 0;
      FILE *fd_in = stdin;
      char *name_in = "stdin";
      pvf_header header;
@@ -31,6 +33,19 @@ int main (int argc, char *argv[])
      check_system();
      program_name = argv[0];
 
+     while ((option = getopt(argc, argv, "hc")) != EOF)
+          {
+
+          switch (option)
+               {
+               case 'c':
+                    cflag = 1;
+                    break;
+               default:
+                    usage();
+               }
+          }
+
      if ((option = getopt(argc, argv, "h")) != EOF)
           usage();
 
@@ -58,5 +73,21 @@ int main (int argc, char *argv[])
      printf("channels: %d\n", header.channels);
      printf("sample speed: %d\n", header.speed);
      printf("bits per sample: %d\n", header.nbits);
+
+     if (cflag)
+	  {
+          int count = 0;
+          int data;
+
+          while (1)
+               {
+	       data = header.read_pvf_data(fd_in);
+	       if (feof(fd_in))
+		    break;
+               ++count;
+               }
+	  printf("samples: %d\n", count);
+	  }
+
      exit(OK);
      }
